#version 120

/*
MotionBlur derived from BSL
*/

#define MotionBlur

#define Saturation 1.30      //[0.0 0.05 0.10 0.15 0.20 0.25 0.30 0.35 0.40 0.45 0.50 0.55 0.60 0.65 0.70 0.75 0.80 0.85 0.90 0.95 1.00 1.05 1.10 1.15 1.20 1.25 1.30 1.35 1.40 1.45 1.50 1.55 1.60 1.65 1.70 1.75 1.80 1.85 1.90 1.95 2.00]

varying vec4 texcoord;

uniform float viewWidth;
uniform float viewHeight;

uniform vec3 cameraPosition;
uniform vec3 previousCameraPosition;

uniform mat4 gbufferProjectionInverse;
uniform mat4 gbufferModelViewInverse;
uniform mat4 gbufferModelView;
uniform mat4 gbufferPreviousModelView;
uniform mat4 gbufferPreviousProjection;

uniform sampler2D colortex0;
uniform sampler2D depthtex1;

#include "/lib/dither.glsl"
#include "/lib/motionBlur.glsl"

float Luminance(in vec3 color)
{
	return dot(color.rgb, vec3(0.2125f, 0.7154f, 0.0721f));
}

void main() {
	vec3 color = texture2D(colortex0,texcoord.xy).rgb;
	
	//Material Flag
	float hand = float(texture2D(depthtex1,texcoord.xy).r < 0.56);
	
	//Motion Blur
	#ifdef MotionBlur
	color = motionBlur(color,hand);
	#endif
	
	color = mix(color, vec3(Luminance(color)), vec3(1.0 - Saturation));

/*DRAWBUFFERS:0*/
	gl_FragData[0] = vec4(color,1.0);

}
